pub struct MockOrganizationsApi {
OrganizationsApi_expectations: MockOrganizationsApi_OrganizationsApi,
}Fields
OrganizationsApi_expectations: MockOrganizationsApi_OrganizationsApiImplementations
Sourceimpl MockOrganizationsApi
impl MockOrganizationsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationsApi
impl MockOrganizationsApi
Sourcepub fn expect_api_key(&mut self) -> &mut Expectation
pub fn expect_api_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the api_key method
Sourcepub fn expect_api_key_information(&mut self) -> &mut Expectation
pub fn expect_api_key_information(&mut self) -> &mut Expectation
Create an Expectation for mocking the api_key_information method
Sourcepub fn expect_create_without_payment(&mut self) -> &mut Expectation
pub fn expect_create_without_payment(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_without_payment method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_auto_enroll_status(&mut self) -> &mut Expectation
pub fn expect_get_auto_enroll_status(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_auto_enroll_status method
Sourcepub fn expect_get_license(&mut self) -> &mut Expectation
pub fn expect_get_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_license method
Sourcepub fn expect_get_public_key(&mut self) -> &mut Expectation
pub fn expect_get_public_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_public_key method
Sourcepub fn expect_get_sso(&mut self) -> &mut Expectation
pub fn expect_get_sso(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_sso method
Sourcepub fn expect_get_subscription(&mut self) -> &mut Expectation
pub fn expect_get_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_subscription method
Sourcepub fn expect_get_user(&mut self) -> &mut Expectation
pub fn expect_get_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_user method
Sourcepub fn expect_leave(&mut self) -> &mut Expectation
pub fn expect_leave(&mut self) -> &mut Expectation
Create an Expectation for mocking the leave method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_cancel(&mut self) -> &mut Expectation
pub fn expect_post_cancel(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_cancel method
Sourcepub fn expect_post_delete_recover_token(&mut self) -> &mut Expectation
pub fn expect_post_delete_recover_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_delete_recover_token method
Sourcepub fn expect_post_keys(&mut self) -> &mut Expectation
pub fn expect_post_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_keys method
Sourcepub fn expect_post_reinstate(&mut self) -> &mut Expectation
pub fn expect_post_reinstate(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_reinstate method
Sourcepub fn expect_post_seat(&mut self) -> &mut Expectation
pub fn expect_post_seat(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_seat method
Sourcepub fn expect_post_sm_subscription(&mut self) -> &mut Expectation
pub fn expect_post_sm_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_sm_subscription method
Sourcepub fn expect_post_sso(&mut self) -> &mut Expectation
pub fn expect_post_sso(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_sso method
Sourcepub fn expect_post_storage(&mut self) -> &mut Expectation
pub fn expect_post_storage(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_storage method
Sourcepub fn expect_post_subscribe_secrets_manager(&mut self) -> &mut Expectation
pub fn expect_post_subscribe_secrets_manager(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_subscribe_secrets_manager method
Sourcepub fn expect_post_subscription(&mut self) -> &mut Expectation
pub fn expect_post_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_subscription method
Sourcepub fn expect_post_upgrade(&mut self) -> &mut Expectation
pub fn expect_post_upgrade(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_upgrade method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_put_collection_management(&mut self) -> &mut Expectation
pub fn expect_put_collection_management(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_collection_management method
Sourcepub fn expect_rotate_api_key(&mut self) -> &mut Expectation
pub fn expect_rotate_api_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the rotate_api_key method